From bc1fe099cca6ba81c357ccc764df1648c978ac86 Mon Sep 17 00:00:00 2001
From: Jacek Antonelli
Date: Thu, 18 Mar 2010 02:15:30 -0500
Subject: Manifest files can now be optional.
If required=False, the manifest won't fail if the file is missing.
---
linden/indra/lib/python/indra/util/llmanifest.py | 9 +++++----
1 file changed, 5 insertions(+), 4 deletions(-)
(limited to 'linden')
--
cgit v1.1
From 78955530d145a08bae5daf3a7c3339f6d6435c8e Mon Sep 17 00:00:00 2001
From: Jacek Antonelli
Date: Thu, 18 Mar 2010 03:13:22 -0500
Subject: ChangeLog.txt is no longer required for packaging.
@nochangelog
---
linden/indra/newview/viewer_manifest.py | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
(limited to 'linden')
diff --git a/linden/indra/newview/viewer_manifest.py b/linden/indra/newview/viewer_manifest.py
index 204bd1f..8c907a3 100755
--- a/linden/indra/newview/viewer_manifest.py
+++ b/linden/indra/newview/viewer_manifest.py
@@ -118,7 +118,7 @@ class ViewerManifest(LLManifest):
self.path("MANIFESTO.txt")
self.path("CONTRIBUTE.txt")
self.path("RELEASE_NOTES.txt")
- self.path("ChangeLog.txt")
+ self.path("ChangeLog.txt", required=False)
self.end_prefix("../../..")
# From the linden directory
--
cgit v1.1
From 8cd94404e0d20361667aae5d18cad256a733b72c Mon Sep 17 00:00:00 2001
From: Jacek Antonelli
Date: Thu, 18 Mar 2010 16:41:31 -0500
Subject: Load login page using Imprudence version instead of SL version.
This will enable us to notify users of updates via the login page.
---
linden/indra/newview/llpanellogin.cpp | 5 +++--
1 file changed, 3 insertions(+), 2 deletions(-)
(limited to 'linden')
diff --git a/linden/indra/newview/llpanellogin.cpp b/linden/indra/newview/llpanellogin.cpp
index e0acd34..d3e295d 100644
--- a/linden/indra/newview/llpanellogin.cpp
+++ b/linden/indra/newview/llpanellogin.cpp
@@ -826,8 +826,9 @@ void LLPanelLogin::loadLoginPage()
}
// Channel and Version
- std::string version = llformat("%d.%d.%d (%d)",
- LL_VERSION_MAJOR, LL_VERSION_MINOR, LL_VERSION_PATCH, LL_VIEWER_BUILD);
+ std::string version = llformat("%d.%d.%d %s",
+ IMP_VERSION_MAJOR, IMP_VERSION_MINOR,
+ IMP_VERSION_PATCH, IMP_VERSION_TEST);
char* curl_channel = curl_escape(gSavedSettings.getString("VersionChannelName").c_str(), 0);
char* curl_version = curl_escape(version.c_str(), 0);
--
cgit v1.1
From fa8c88026ed70eff10dee9c6d53916eebadc0df1 Mon Sep 17 00:00:00 2001
From: Jacek Antonelli
Date: Sat, 27 Mar 2010 18:45:30 -0500
Subject: Removed Second Life from the default grid list.
Second Life is no longer officially supported, due to TPV Policy concerns.
---
linden/indra/newview/app_settings/default_grids.xml | 14 --------------
linden/indra/newview/app_settings/settings.xml | 2 +-
linden/indra/newview/hippoGridManager.cpp | 12 +++++-------
3 files changed, 6 insertions(+), 22 deletions(-)
(limited to 'linden')
diff --git a/linden/indra/newview/app_settings/default_grids.xml b/linden/indra/newview/app_settings/default_grids.xml
index 13293cf..f11f513 100644
--- a/linden/indra/newview/app_settings/default_grids.xml
+++ b/linden/indra/newview/app_settings/default_grids.xml
@@ -10,20 +10,6 @@
default_grids_version0
-
-
-
KeepAppearance
- LoggedIntoOpenSim
-
LoginAsGod
diff --git a/linden/indra/lib/python/indra/util/llmanifest.py b/linden/indra/lib/python/indra/util/llmanifest.py
index 369cc81..7a2505d 100644
--- a/linden/indra/lib/python/indra/util/llmanifest.py
+++ b/linden/indra/lib/python/indra/util/llmanifest.py
@@ -608,7 +608,7 @@ class LLManifest(object):
d = src_re.sub(d_template, s.replace('\\', '/'))
yield os.path.normpath(s), os.path.normpath(d)
- def path(self, src, dst=None):
+ def path(self, src, dst=None, required=True):
sys.stdout.write("Processing %s => %s ... " % (src, dst))
sys.stdout.flush()
if src == None:
@@ -625,9 +625,10 @@ class LLManifest(object):
assert(s != d)
count += self.process_file(s, d)
else:
- # if we're specifying a single path (not a glob),
- # we should error out if it doesn't exist
- self.check_file_exists(src)
+ # if we're specifying a single path (not a glob), and
+ # it's required, error out if it doesn't exist
+ if required:
+ self.check_file_exists(src)
# if it's a directory, recurse through it
if os.path.isdir(src):
count += self.process_directory(src, dst)
--
cgit v1.1
From 0f3d6ce1fb4b7d581b7e18e940e03cffe5e098ce Mon Sep 17 00:00:00 2001
From: Jacek Antonelli
Date: Thu, 18 Mar 2010 03:09:14 -0500
Subject: Improved make_changelog.py.
* Uses 'subprocess' module instead of 'commands' (which is Unix-only).
* No longer overwrites ChangeLog.txt when it fails.
@nochangelog
---
linden/scripts/make_changelog.py | 59 ++++++++++++++++++++++++++--------------
1 file changed, 39 insertions(+), 20 deletions(-)
(limited to 'linden')
diff --git a/linden/scripts/make_changelog.py b/linden/scripts/make_changelog.py
index 43745a4..713adc1 100755
--- a/linden/scripts/make_changelog.py
+++ b/linden/scripts/make_changelog.py
@@ -50,9 +50,7 @@
#
-
-import commands, re, os, sys
-from string import Template
+import re, os, sys, subprocess
SCRIPT_DIR = os.path.abspath( os.path.dirname( sys.argv[0] ) )
@@ -316,8 +314,9 @@ Author: %(an)s <%(ae)s>""" % { "ad" : self.author_date,
"id" : self.id[0:7] })
if self.commit_name != self.author_name:
- texts.append("Committer: %(cn)s <%(ce)s>" % { "cn" : self.commit_name,
- "ce" : self.commit_mail })
+ texts.append("Committer: %(cn)s <%(ce)s>" % \
+ { "cn" : self.commit_name,
+ "ce" : self.commit_mail })
texts.append("\n")
@@ -360,32 +359,52 @@ Author: %(an)s <%(ae)s>""" % { "ad" : self.author_date,
+def fail( reason, abort=False ):
+ """Prints a message that the ChangeLog couldn't be generated, then
+ exits the script. If abort is True, exit with status code 1 (to
+ indicate that Make/VisualStudio/Xcode/etc. should abort),
+ otherwise exit with status code 0."""
+
+ if abort:
+ print "Error: Could not generate ChangeLog.txt: " + reason
+ exit(1)
+ else:
+ print "Warning: Could not generate ChangeLog.txt: " + reason
+ exit(0)
+
+
def main():
commits = sys.argv[1:]
- if commits:
- commits = " ".join(commits)
- else:
- commits = "HEAD"
+ if not commits:
+ commits = ["HEAD"]
# Set PATH to help find the git executable on Mac OS X.
if sys.platform == "darwin":
os.environ["PATH"] += ":/usr/local/bin:/usr/local/git/bin:/sw/bin:/opt/bin:~/bin"
- # Fetch the log entries from git in one big chunk.
- cmd = "git log --pretty=fuller --name-status --date=short --date-order " + commits
- status, output = commands.getstatusoutput(cmd)
-
- # If the git command failed, write a placeholder ChangeLog.txt and exit.
+ # Fetch the log entries from git in one big chunk.
+ cmd = ["git", "log", "--pretty=fuller", "--name-status",
+ "--date=short", "--date-order"] + commits
+
+ try:
+ proc = subprocess.Popen(cmd,
+ cwd = ROOT_DIR,
+ stdout = subprocess.PIPE,
+ stderr = subprocess.STDOUT,
+ shell = True)
+ except OSError:
+ fail("The 'git' command is not available.")
+
+ output = proc.communicate()[0]
+ status = proc.returncode
+
+
+ # If the git command failed, print the reason and exit.
if status != 0:
- print "Could not generate ChangeLog.txt: " + output
- changelog = open(CHANGELOG, "w")
- changelog.write( output + "\n (Imprudence must be compiled from a Git repository to generate a ChangeLog.)\n\n")
- changelog.close()
- exit(0)
-
+ fail(output)
# Split it up into individual commits.
logs = re.compile("^commit ", re.MULTILINE).split(output)[1:]